Usage
=====

To run a simple case of JAX-in-Cell, call:

.. code-block:: console

    jaxincell

To use a TOML input file:

.. code-block:: console

    jaxincell example_input.toml

To run the example script:

.. code-block:: console

    python example_script.py
